<?php
declare(strict_types=1);

namespace Flat101\EnhancedEcommerce\Observer;

use Flat101\EnhancedEcommerce\Model\DataLayer\Generator\Product;
use Flat101\EnhancedEcommerce\Model\Session;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Quote\Model\Quote\Item;
use Psr\Log\LoggerInterface;

class SalesQuoteRemoveItemObserver implements ObserverInterface
{
    /** @var Product */
    private $productGenerator;

    /** @var Session */
    private $sessionManager;

    /** @var LoggerInterface */
    private $logger;

    public function __construct(
        Product $productGenerator,
        Session $sessionManager,
        LoggerInterface $logger
    ) {
        $this->productGenerator = $productGenerator;
        $this->sessionManager = $sessionManager;
        $this->logger = $logger;
    }

    /**
     * {@inheritdoc}
     */
    public function execute(Observer $observer): void
    {
        try {
            /** @var Item $item */
            $item = $observer->getEvent()->getData('quote_item');
            $product = $this->productGeneratorUa->generate($item->getProduct(), $item->getQty(), $item);
            $this->sessionManager->setRemovedProductFromCart($product);

            $product = $this->productGeneratorGa4->generate($item->getProduct(), $item->getQty(), $item);
            $this->sessionManager->setRemovedProductFromCart($product);
        } catch (\Exception $e) {
            $this->logger->critical($e->getMessage());
        }
    }
}
